@@ -18,30 +18,32 @@
   @author Allen Winter \<winter@kde.org\>
 */
 #include "attachmenthandler.h"
-#include "calendarsupport_debug.h"
 #include "calendarsupport/utils.h"
+#include "calendarsupport_debug.h"
 
 #include <ItemFetchJob>
 
+#include <KIO/FileCopyJob>
+#include <KIO/JobUiDelegate>
+#include <KIO/OpenUrlJob>
+#include <KIO/StatJob>
+#include <KJob>
+#include <KJobWidgets>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KRun>
-#include <KIO/FileCopyJob>
-#include <KIO/StatJob>
-#include <KJobWidgets>
-#include <KJob>
 
-#include <QFileDialog>
-#include <QTemporaryFile>
-#include <QFile>
-#include <QPointer>
-#include <QMimeDatabase>
 #include <QDesktopServices>
+#include <QFile>
+#include <QFileDialog>
+#include <QMimeDatabase>
+#include <QPointer>
+#include <QTemporaryFile>
 
 using namespace KCalendarCore;
 using namespace Akonadi;
 
-namespace CalendarSupport {
+namespace CalendarSupport
+{
 struct ReceivedInfo {
     QString uid;
     QString attachmentName;
@@ -59,7 +61,8 @@ public:
     QPointer<QWidget> const mParent;
 };
 
-AttachmentHandler::AttachmentHandler(QWidget *parent) : QObject(parent)
+AttachmentHandler::AttachmentHandler(QWidget *parent)
+    : QObject(parent)
     , d(new Private(parent))
 {
 }
@@ -91,9 +94,7 @@ Attachment AttachmentHandler::find(const QString &attachmentName, const Incidenc
     }
 
     if (a.isEmpty()) {
-        KMessageBox::error(
-            d->mParent,
-            i18n("No attachment named \"%1\" found in the incidence.", attachmentName));
+        KMessageBox::error(d->mParent, i18n("No attachment named \"%1\" found in the incidence.", attachmentName));
         return Attachment();
     }
 
@@ -104,8 +105,7 @@ Attachment AttachmentHandler::find(const QString &attachmentName, const Incidenc
         if (!job->exec()) {
             KMessageBox::sorry(
                 d->mParent,
-                i18n("The attachment \"%1\" is a web link that is inaccessible from this computer. ",
-                     QUrl::fromPercentEncoding(a.uri().toLatin1())));
+                i18n("The attachment \"%1\" is a web link that is inaccessible from this computer. ", QUrl::fromPercentEncoding(a.uri().toLatin1())));
             return Attachment();
         }
     }
@@ -120,10 +120,9 @@ Attachment AttachmentHandler::find(const QString &attachmentName, const Schedule
 
     Incidence::Ptr incidence = message->event().dynamicCast<Incidence>();
     if (!incidence) {
-        KMessageBox::error(
-            d->mParent,
-            i18n("The calendar invitation stored in this email message is broken in some way. "
-                 "Unable to continue."));
+        KMessageBox::error(d->mParent,
+                           i18n("The calendar invitation stored in this email message is broken in some way. "
+                                "Unable to continue."));
         return Attachment();
     }
 
@@ -139,9 +138,7 @@ static QUrl tempFileForAttachment(const Attachment &attachment)
     QMimeDatabase db;
     QStringList patterns = db.mimeTypeForName(attachment.mimeType()).globPatterns();
     if (!patterns.empty()) {
-        s_tempFile = new QTemporaryFile(QDir::tempPath() + QLatin1String(
-                                            "/attachementview_XXXXXX")
-                                        + patterns.first().remove(QLatin1Char('*')));
+        s_tempFile = new QTemporaryFile(QDir::tempPath() + QLatin1String("/attachementview_XXXXXX") + patterns.first().remove(QLatin1Char('*')));
     } else {
         s_tempFile = new QTemporaryFile();
     }
@@ -152,7 +149,7 @@ static QUrl tempFileForAttachment(const Attachment &attachment)
     s_tempFile->close();
     QFile tf(s_tempFile->fileName());
     if (tf.size() != attachment.size()) {
-        //whoops. failed to write the entire attachment. return an invalid URL.
+        // whoops. failed to write the entire attachment. return an invalid URL.
         delete s_tempFile;
         s_tempFile = nullptr;
         return url;
@@ -175,15 +172,13 @@ bool AttachmentHandler::view(const Attachment &attachment)
         // put the attachment in a temporary file and launch it
         QUrl tempUrl = tempFileForAttachment(attachment);
         if (tempUrl.isValid()) {
-            KRun::RunFlags flags;
-            flags |= KRun::DeleteTemporaryFiles;
-            flags |= KRun::RunExecutables;
-            stat = KRun::runUrl(tempUrl, attachment.mimeType(), nullptr, flags);
+            KIO::OpenUrlJob *job = new KIO::OpenUrlJob(tempUrl, attachment.mimeType());
+            job->setDeleteTemporaryFile(true);
+            job->setRunExecutables(true);
+            job->start();
         } else {
             stat = false;
-            KMessageBox::error(
-                d->mParent,
-                i18n("Unable to create a temporary file for the attachment."));
+            KMessageBox::error(d->mParent, i18n("Unable to create a temporary file for the attachment."));
         }
         delete s_tempFile;
         s_tempFile = nullptr;
@@ -200,7 +195,7 @@ void AttachmentHandler::view(const QString &attachmentName, const QString &uid)
 {
     Item item;
     item.setGid(uid);
-    auto *job = new ItemFetchJob(item);
+    auto job = new ItemFetchJob(item);
     connect(job, &ItemFetchJob::result, this, &AttachmentHandler::slotFinishView);
     ReceivedInfo info;
     info.attachmentName = attachmentName;
@@ -216,9 +211,7 @@ bool AttachmentHandler::view(const QString &attachmentName, const ScheduleMessag
 bool AttachmentHandler::saveAs(const Attachment &attachment)
 {
     // get the saveas file name
-    const QString saveAsFile = QFileDialog::getSaveFileName(d->mParent, i18n(
-                                                                "Save Attachment"),
-                                                            attachment.label());
+    const QString saveAsFile = QFileDialog::getSaveFileName(d->mParent, i18n("Save Attachment"), attachment.label());
     if (saveAsFile.isEmpty()) {
         return false;
     }
@@ -239,9 +232,7 @@ bool AttachmentHandler::saveAs(const Attachment &attachment)
             }
         } else {
             stat = false;
-            KMessageBox::error(
-                d->mParent,
-                i18n("Unable to create a temporary file for the attachment."));
+            KMessageBox::error(d->mParent, i18n("Unable to create a temporary file for the attachment."));
         }
         delete s_tempFile;
         s_tempFile = nullptr;
@@ -258,7 +249,7 @@ void AttachmentHandler::saveAs(const QString &attachmentName, const QString &uid
 {
     Item item;
     item.setGid(uid);
-    auto *job = new ItemFetchJob(item);
+    auto job = new ItemFetchJob(item);
     connect(job, &ItemFetchJob::result, this, &AttachmentHandler::slotFinishView);
 
     ReceivedInfo info;
@@ -278,7 +269,7 @@ void AttachmentHandler::slotFinishSaveAs(KJob *job)
     bool success = false;
 
     if (job->error() != 0) {
-        auto *fetchJob = qobject_cast<ItemFetchJob *>(job);
+        auto fetchJob = qobject_cast<ItemFetchJob *>(job);
         const Item::List items = fetchJob->items();
         if (!items.isEmpty()) {
             Incidence::Ptr incidence = CalendarSupport::incidence(items.first());
@@ -300,7 +291,7 @@ void AttachmentHandler::slotFinishView(KJob *job)
     bool success = false;
 
     if (job->error()) {
-        auto *fetchJob = qobject_cast<ItemFetchJob *>(job);
+        auto fetchJob = qobject_cast<ItemFetchJob *>(job);
         const Item::List items = fetchJob->items();
         if (!items.isEmpty()) {
             Incidence::Ptr incidence = CalendarSupport::incidence(items.first());
