@@ -1,24 +1,8 @@
 /*
-  Copyright (c) 1998 Preston Brown <pbrown@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 1998 Preston Brown <pbrown@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "calprinter.h"
@@ -30,16 +14,15 @@
 #include <KStandardGuiItem>
 #include <QVBoxLayout>
 
+#include <KConfigGroup>
 #include <QButtonGroup>
+#include <QDialogButtonBox>
 #include <QGridLayout>
 #include <QGroupBox>
 #include <QPrintDialog>
 #include <QPrintPreviewDialog>
 #include <QSplitter>
 #include <QStackedWidget>
-#include <KConfigGroup>
-#include <QDialogButtonBox>
-#include <QPushButton>
 
 #include <PimCommon/KPimPrintPreviewDialog>
 
@@ -57,7 +40,7 @@ CalPrinter::CalPrinter(QWidget *parent, const Akonadi::ETMCalendar::Ptr &calenda
 
 CalPrinter::~CalPrinter()
 {
-    mPrintPlugins.clear();
+    qDeleteAll(mPrintPlugins);
     delete mConfig;
 }
 
@@ -65,6 +48,7 @@ void CalPrinter::init(const Akonadi::ETMCalendar::Ptr &calendar)
 {
     mCalendar = calendar;
 
+    qDeleteAll(mPrintPlugins);
     mPrintPlugins.clear();
 
     if (!mUniqItem) {
@@ -104,10 +88,9 @@ void CalPrinter::print(int type, const QDate &fd, const QDate &td, const KCalend
     for (it = mPrintPlugins.begin(); it != end; ++it) {
         (*it)->setSelectedIncidences(selectedIncidences);
     }
-    QPointer<CalPrintDialog> printDialog
-        = new CalPrintDialog(type, mPrintPlugins, mParent, mUniqItem);
+    QPointer<CalPrintDialog> printDialog = new CalPrintDialog(type, mPrintPlugins, mParent, mUniqItem);
 
-    KConfigGroup grp(mConfig, "");   //orientation setting isn't in a group
+    KConfigGroup grp(mConfig, ""); // orientation setting isn't in a group
     printDialog->setOrientation(CalPrinter::ePrintOrientation(grp.readEntry("Orientation", 1)));
     printDialog->setPreview(preview);
     setDateRange(fd, td);
@@ -131,33 +114,28 @@ void CalPrinter::print(int type, const QDate &fd, const QDate &td, const KCalend
 void CalPrinter::doPrint(PrintPlugin *selectedStyle, CalPrinter::ePrintOrientation dlgorientation, bool preview)
 {
     if (!selectedStyle) {
-        KMessageBox::error(
-            mParent,
-            i18nc("@info", "Unable to print, an invalid print style was specified."),
-            i18nc("@title:window", "Printing error"));
+        KMessageBox::error(mParent, i18nc("@info", "Unable to print, an invalid print style was specified."), i18nc("@title:window", "Printing error"));
         return;
     }
 
     QPrinter printer;
     switch (dlgorientation) {
     case eOrientPlugin:
-        printer.setOrientation(selectedStyle->defaultOrientation());
+        printer.setPageOrientation(selectedStyle->defaultOrientation());
         break;
     case eOrientPortrait:
-        printer.setOrientation(QPrinter::Portrait);
+        printer.setPageOrientation(QPageLayout::Portrait);
         break;
     case eOrientLandscape:
-        printer.setOrientation(QPrinter::Landscape);
+        printer.setPageOrientation(QPageLayout::Landscape);
         break;
     case eOrientPrinter:
         break;
     }
 
     if (preview) {
-        QPointer<PimCommon::KPimPrintPreviewDialog> printPreview
-            = new PimCommon::KPimPrintPreviewDialog(&printer);
-        connect(printPreview.data(), &QPrintPreviewDialog::paintRequested, this,
-                [selectedStyle, &printer]() {
+        QPointer<PimCommon::KPimPrintPreviewDialog> printPreview = new PimCommon::KPimPrintPreviewDialog(&printer);
+        connect(printPreview.data(), &QPrintPreviewDialog::paintRequested, this, [selectedStyle, &printer]() {
             selectedStyle->doPrint(&printer);
         });
         printPreview->exec();
@@ -179,9 +157,8 @@ CalPrintDialog::CalPrintDialog(int initialPrintType, const PrintPlugin::List &pl
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Print"));
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(
-        QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto mainLayout = new QVBoxLayout(this);
     mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     mOkButton->setDefault(true);
     mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -189,12 +166,12 @@ CalPrintDialog::CalPrintDialog(int initialPrintType, const PrintPlugin::List &pl
     connect(buttonBox, &QDialogButtonBox::rejected, this, &CalPrintDialog::reject);
     setModal(true);
     QWidget *page = new QWidget(this);
-    QVBoxLayout *pageVBoxLayout = new QVBoxLayout(page);
+    auto pageVBoxLayout = new QVBoxLayout(page);
     pageVBoxLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->addWidget(page);
     mainLayout->addWidget(buttonBox);
 
-    QSplitter *splitter = new QSplitter(page);
+    auto splitter = new QSplitter(page);
     pageVBoxLayout->addWidget(splitter);
     splitter->setOrientation(Qt::Horizontal);
     splitter->setChildrenCollapsible(false);
@@ -203,10 +180,10 @@ CalPrintDialog::CalPrintDialog(int initialPrintType, const PrintPlugin::List &pl
     mTypeGroup = new QButtonGroup(typeBox);
 
     QWidget *splitterRight = new QWidget(splitter);
-    QGridLayout *splitterRightLayout = new QGridLayout(splitterRight);
+    auto splitterRightLayout = new QGridLayout(splitterRight);
     splitterRightLayout->setContentsMargins(0, 0, 0, 0);
-    //splitterRightLayout->setMargin( marginHint() );
-    //splitterRightLayout->setSpacing( spacingHint() );
+    // splitterRightLayout->setMargin( marginHint() );
+    // splitterRightLayout->setSpacing( spacingHint() );
 
     mConfigArea = new QStackedWidget(splitterRight);
     splitterRightLayout->addWidget(mConfigArea, 0, 0, 1, 2);
@@ -215,33 +192,25 @@ CalPrintDialog::CalPrintDialog(int initialPrintType, const PrintPlugin::List &pl
     splitterRightLayout->addWidget(orientationLabel, 1, 0);
 
     mOrientationSelection = new QComboBox(splitterRight);
-    mOrientationSelection->setToolTip(
-        i18nc("@info:tooltip", "Set the print orientation"));
-    mOrientationSelection->setWhatsThis(
-        i18nc("@info:whatsthis",
-              "Choose if you want your output to be printed in \"portrait\" or "
-              "\"landscape\". You can also default to the orientation best suited to "
-              "the selected style or to your printer's default setting."));
-    mOrientationSelection->addItem(i18nc("@item:inlistbox",
-                                         "Use Default Orientation of Selected Style"));
-    mOrientationSelection->addItem(i18nc("@item:inlistbox",
-                                         "Use Printer Default"));
-    mOrientationSelection->addItem(i18nc("@item:inlistbox",
-                                         "Portrait"));
-    mOrientationSelection->addItem(i18nc("@item:inlistbox",
-                                         "Landscape"));
+    mOrientationSelection->setToolTip(i18nc("@info:tooltip", "Set the print orientation"));
+    mOrientationSelection->setWhatsThis(i18nc("@info:whatsthis",
+                                              "Choose if you want your output to be printed in \"portrait\" or "
+                                              "\"landscape\". You can also default to the orientation best suited to "
+                                              "the selected style or to your printer's default setting."));
+    mOrientationSelection->addItem(i18nc("@item:inlistbox", "Use Default Orientation of Selected Style"));
+    mOrientationSelection->addItem(i18nc("@item:inlistbox", "Use Printer Default"));
+    mOrientationSelection->addItem(i18nc("@item:inlistbox", "Portrait"));
+    mOrientationSelection->addItem(i18nc("@item:inlistbox", "Landscape"));
     splitterRightLayout->addWidget(mOrientationSelection, 1, 1);
 
     // signals and slots connections
-    connect(mTypeGroup, QOverload<QAbstractButton *>::of(
-                &QButtonGroup::buttonClicked), this, &CalPrintDialog::setPrintType);
+    connect(mTypeGroup, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), this, &CalPrintDialog::setPrintType);
     orientationLabel->setBuddy(mOrientationSelection);
 
     // First insert the config widgets into the widget stack. This possibly assigns
     // proper ids (when two plugins have the same sortID), so store them in a map
     // and use these new IDs to later sort the plugins for the type selection.
-    for (PrintPlugin::List::ConstIterator it = plugins.constBegin(), total = plugins.constEnd();
-         it != total; ++it) {
+    for (PrintPlugin::List::ConstIterator it = plugins.constBegin(), total = plugins.constEnd(); it != total; ++it) {
         int newid = mConfigArea->insertWidget((*it)->sortID(), (*it)->configWidget(mConfigArea));
         mPluginIDs[newid] = (*it);
     }
@@ -253,14 +222,12 @@ CalPrintDialog::CalPrintDialog(int initialPrintType, const PrintPlugin::List &pl
         PrintPlugin *p = mapit.value();
         QRadioButton *radioButton = new QRadioButton(p->description());
         radioButton->setEnabled(p->enabled());
-        radioButton->setToolTip(
-            i18nc("@info:tooltip", "Select the type of print"));
-        radioButton->setWhatsThis(
-            i18nc("@info:whatsthis",
-                  "Select one of the following types of prints you want to make. "
-                  "You may want to print an individual item, or all the items for a "
-                  "specific time range (like a day, week or month), or you may want "
-                  "to print your to-do list."));
+        radioButton->setToolTip(i18nc("@info:tooltip", "Select the type of print"));
+        radioButton->setWhatsThis(i18nc("@info:whatsthis",
+                                        "Select one of the following types of prints you want to make. "
+                                        "You may want to print an individual item, or all the items for a "
+                                        "specific time range (like a day, week or month), or you may want "
+                                        "to print your to-do list."));
         // Check the first available button (to ensure one is selected initially) and then
         // the button matching the desired print type -- if such is available!
         if ((firstButton || p->sortID() == initialPrintType) && p->enabled()) {
@@ -336,8 +303,7 @@ PrintPlugin *CalPrintDialog::selectedPlugin()
 
 void CalPrintDialog::slotOk()
 {
-    mOrientation
-        = static_cast<CalPrinter::ePrintOrientation>(mOrientationSelection->currentIndex());
+    mOrientation = static_cast<CalPrinter::ePrintOrientation>(mOrientationSelection->currentIndex());
 
     QMap<int, PrintPlugin *>::ConstIterator it = mPluginIDs.constBegin();
     for (; it != mPluginIDs.constEnd(); ++it) {
